@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sieveconditionwidgetlister.h"
-#include "autocreatescriptdialog.h"
 #include "autocreatescriptutil_p.h"
 #include "commonwidgets/sievehelpbutton.h"
 #include "libksieve_debug.h"
@@ -83,26 +82,23 @@ void SieveConditionWidget::initWidget()
     mComboBox->setEditable(false);
 
     const QList<KSieveUi::SieveCondition *> list = KSieveUi::SieveConditionList::conditionList(mSieveGraphicalModeWidget);
-    QList<KSieveUi::SieveCondition *>::const_iterator it;
-    QList<KSieveUi::SieveCondition *>::const_iterator end(list.constEnd());
-    int index = 0;
-    for (index = 0, it = list.constBegin(); it != end; ++it, ++index) {
-        if ((*it)->needCheckIfServerHasCapability()) {
-            if (mSieveGraphicalModeWidget->sieveCapabilities().contains((*it)->serverNeedsCapability())) {
+    for (const auto &action : list) {
+        if (action->needCheckIfServerHasCapability()) {
+            if (mSieveGraphicalModeWidget->sieveCapabilities().contains(action->serverNeedsCapability())) {
                 // append to the list of actions:
-                mConditionList.append(*it);
-                connect(*it, &SieveCondition::valueChanged, this, &SieveConditionWidget::valueChanged);
+                mConditionList.append(action);
+                connect(action, &SieveCondition::valueChanged, this, &SieveConditionWidget::valueChanged);
                 // add (i18n-ized) name to combo box
-                mComboBox->addItem((*it)->label(), (*it)->name());
+                mComboBox->addItem(action->label(), action->name());
             } else {
-                delete (*it);
+                delete action;
             }
         } else {
             // append to the list of actions:
-            mConditionList.append(*it);
-            connect(*it, &SieveCondition::valueChanged, this, &SieveConditionWidget::valueChanged);
+            mConditionList.append(action);
+            connect(action, &SieveCondition::valueChanged, this, &SieveConditionWidget::valueChanged);
             // add (i18n-ized) name to combo box
-            mComboBox->addItem((*it)->label(), (*it)->name());
+            mComboBox->addItem(action->label(), action->name());
         }
     }
 
@@ -118,7 +114,7 @@ void SieveConditionWidget::initWidget()
 
     mComboBox->addItem(QLatin1String(""));
     mLayout->addWidget(mComboBox, 1, 2);
-    connect(mComboBox, QOverload<int>::of(&QComboBox::activated), this, &SieveConditionWidget::slotConditionChanged);
+    connect(mComboBox, &QComboBox::activated, this, &SieveConditionWidget::slotConditionChanged);
 
     mComboBox->setMaxCount(mComboBox->count());
     mComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed));
@@ -151,7 +147,7 @@ void SieveConditionWidget::slotAddComment()
     if (index < mConditionList.count()) {
         KSieveUi::SieveCondition *condition = mConditionList.at(index);
         const QString comment = condition->comment();
-        QPointer<SieveScriptDescriptionDialog> dlg = new SieveScriptDescriptionDialog;
+        QPointer<SieveScriptDescriptionDialog> dlg = new SieveScriptDescriptionDialog(this);
         dlg->setDescription(comment);
         if (dlg->exec()) {
             condition->setComment(dlg->description());
@@ -237,9 +233,7 @@ SieveConditionWidgetLister::SieveConditionWidgetLister(SieveEditorGraphicalModeW
     updateAddRemoveButton();
 }
 
-SieveConditionWidgetLister::~SieveConditionWidgetLister()
-{
-}
+SieveConditionWidgetLister::~SieveConditionWidgetLister() = default;
 
 void SieveConditionWidgetLister::slotAddWidget(QWidget *w)
 {
@@ -354,10 +348,18 @@ void SieveConditionWidgetLister::loadScript(QXmlStreamReader &element, bool uniq
             element.readNextStartElement();
         }
         while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             const QStringRef tagName = element.name();
+#else
+            const QStringView tagName = element.name();
+#endif
             if (tagName == QLatin1String("testlist")) {
                 while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                     const QStringRef testTagName = element.name();
+#else
+                    const QStringView testTagName = element.name();
+#endif
                     if (testTagName == QLatin1String("test")) {
                         if (element.attributes().hasAttribute(QLatin1String("name"))) {
                             QString conditionName = element.attributes().value(QLatin1String("name")).toString();
