@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,7 +9,6 @@
 #include "widgets/abstractselectemaillineedit.h"
 #include "widgets/moveimapfolderwidget.h"
 #include <KPluginFactory>
-#include <KPluginLoader>
 #include <QHBoxLayout>
 #include <QStackedWidget>
 
@@ -47,9 +46,7 @@ VacationMailActionWidget::VacationMailActionWidget(QWidget *parent)
     setEnabled(false);
 }
 
-VacationMailActionWidget::~VacationMailActionWidget()
-{
-}
+VacationMailActionWidget::~VacationMailActionWidget() = default;
 
 void VacationMailActionWidget::setSieveImapAccountSettings(const KSieveUi::SieveImapAccountSettings &account)
 {
@@ -97,6 +94,6 @@ QString VacationMailActionWidget::mailActionRecipient(bool &valid) const
         valid = mSelectEmailLineEdit->isValid();
         return mSelectEmailLineEdit->text();
     } else {
-        return QString();
+        return {};
     }
 }
